@@ -1,13 +1,15 @@
 import matplotlib.pyplot as plt
 import datetime
 
-def plotting_scores(data):
+
+def plotting_scores(data, save_png=True):
+
     """
 
     Parameters
     ----------
     data :
-        
+
 
     Returns
     -------
@@ -15,8 +17,7 @@ def plotting_scores(data):
     """
     start = datetime.datetime.now()
 
-
-    plt.rcParams["figure.figsize"] = (10,10)
+    plt.rcParams["figure.figsize"] = (10, 10)
     plt.scatter(list(range(len(data))), data)
     plt.plot(data)
     plt.xticks(data.index)
@@ -24,6 +25,8 @@ def plotting_scores(data):
     plt.grid()
     plt.title('Energy resolution after each iteration')
     plt.xlabel('Iteration number')
-    plt.ylabel('Found minimum $\dfrac{\sigma}{E}$%')
-    # plt.show()
-    plt.savefig(f'python_scripts/data/pcts/{start}.png')
\ No newline at end of file
+    plt.ylabel('Found minimum')  
+    if save_png==True:
+        plt.savefig(f'python_scripts/data/pcts/{start}.png')
+
+    plt.show()
